<?xml version="1.0"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="redirect"
	exclude-result-prefixes="xs"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
    xmlns:xalan="http://xml.apache.org/xalan"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:output method="html" encoding="UTF-8"
		omit-xml-declaration="yes" indent="yes"
		doctype-public="-//W3C//DTD XHTML 1.0 Frameset//EN"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd" />

	<!-- Application can use these parameters to pass in the  -->
	<!-- schema file name and schema location                 -->
	<xsl:param name="xmlschemaName" select="'input-schema-name'" />
	<xsl:param name="xmlschemaLocation" select="'./input-schema-name'" />
	<xsl:param name="decodedXMLSchemaLocation"
		select="'./decoded-schema-name'" />
	<xsl:param name="globalBaseDir" select="'./'" />
	<xsl:param name="outputFolder" select="'./'" />

	<xsl:include href="xdsource.xsl" />

	<xsl:strip-space elements="*" />

	<xsl:variable name="schemaFileLocation">
		<xsl:choose>
			<xsl:when test="contains(@schemaLocation, ':')">
				<xsl:value-of select="@schemaLocation" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of
					select="concat($globalBaseDir, @schemaLocation)" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- ================================================================== -->
	<!--    Define a list of keys for comparisons                           -->
	<!-- ================================================================== -->
	<xsl:key name="typeDefinitions" match="/xs:schema/xs:simpleType"
		use="concat('{', ../@targetNamespace, '}', @name)" />
	<xsl:key name="typeDefinitions" match="/xs:schema/xs:complexType"
		use="concat('{', ../@targetNamespace, '}', @name)" />
	<xsl:key name="typeDefinitions"
		match="/xs:schema/xs:redefine/xs:simpleType"
		use="concat('{', ../../@targetNamespace, '}', @name)" />
	<xsl:key name="typeDefinitions"
		match="/xs:schema/xs:redefine/xs:complexType"
		use="concat('{', ../../@targetNamespace, '}', @name)" />

	<xsl:key name="attributeDeclarations"
		match="/xs:schema/xs:attribute"
		use="concat('{', ../@targetNamespace, '}', @name)" />
	<xsl:key name="elementDeclarations" match="/xs:schema/xs:element"
		use="concat('{', ../@targetNamespace, '}', @name)" />

	<xsl:key name="attributeGroupDefinitions"
		match="/xs:schema/xs:attributeGroup"
		use="concat('{', ../@targetNamespace, '}', @name)" />
	<xsl:key name="attributeGroupDefinitions"
		match="/xs:schema/xs:redefine/xs:attributeGroup"
		use="concat('{', ../../@targetNamespace, '}', @name)" />

	<xsl:key name="groupDefinitions" match="/xs:schema/xs:group"
		use="concat('{', ../@targetNamespace, '}', @name)" />
	<xsl:key name="groupDefinitions"
		match="/xs:schema/xs:redefine/xs:group"
		use="concat('{', ../../@targetNamespace, '}', @name)" />

	<xsl:key name="notationDeclarations" match="/xs:schema/xs:notation"
		use="concat('{', ../@targetNamespace, '}', @name)" />


	<!-- ================================================================== -->
	<!--                        XML Schema                                  -->
	<!-- ================================================================== -->
	<xsl:template match="xs:schema">

		<HTML>
			<HEAD>
				<xsl:apply-templates select="." mode="docHeader">
				</xsl:apply-templates>
			</HEAD>
			<BODY BGCOLOR="white">
				<FONT size="+1" CLASS="FrameHeadingFont">
					<b>XSD Documentation</b>
				</FONT>
				<P></P>
				<A HREF="overall.html" TARGET="listFrame">
					All Schemas
				</A>
				<P></P>
				<FONT size="+1" CLASS="FrameHeadingFont">Schemas</FONT>
				<P></P>
				<xsl:apply-templates select="."
					mode="docBodyOverview">
					<xsl:with-param name="schemaLocation"
						select="$decodedXMLSchemaLocation" />
					<xsl:with-param name="baseDir"
						select="xalan:nodeset($baseInputDir)" />
				</xsl:apply-templates>
				<P></P>
			</BODY>
		</HTML>

		<xsl:variable name="overallOutputPath">
			<xsl:value-of
				select="concat($outputFolder, 'overall.html')" />
		</xsl:variable>

		<xsl:variable name="pathOfIndex">
			<xsl:value-of select="concat($outputFolder, 'index.html')" />
		</xsl:variable>


		<redirect:write select="$pathOfIndex" method="html">
			<xsl:variable name="title"
				select="'XML Schema Documentation'" />
			<HTML>
				<HEAD>
					<TITLE>
						XSD Documentation for
						<xsl:value-of select="$xmlschemaName" />
					</TITLE>
				</HEAD>
				<FRAMESET cols="20%,80%">
					<FRAMESET rows="30%,70%">
						<xsl:text disable-output-escaping="yes">
							&lt;FRAME src=&quot;
						</xsl:text>
						xsdMain.html
						<xsl:text disable-output-escaping="yes">
							&quot; name=&quot;defListFrame&quot;&gt;
						</xsl:text>
						<xsl:text disable-output-escaping="yes">
							&lt;/FRAME&gt;
						</xsl:text>

						<xsl:text disable-output-escaping="yes">
							&lt;FRAME src=&quot;
						</xsl:text>
						overall.html
						<xsl:text disable-output-escaping="yes">
							&quot; name=&quot;listFrame&quot;&gt;
						</xsl:text>
						<xsl:text disable-output-escaping="yes">
							&lt;/FRAME&gt;
						</xsl:text>
					</FRAMESET>
					<xsl:text disable-output-escaping="yes">
						&lt;FRAME src=&quot;
					</xsl:text>
					<!-- <xsl:value-of select="concat(substring-before($, '.xsd'), '.html')"/> -->
					<xsl:value-of
						select="concat(substring-before($xmlschemaName, '.xsd'), 'Details.html')" />
					<xsl:text disable-output-escaping="yes">
						&quot; name=&quot;detailFrame&quot;&gt;
					</xsl:text>
					<xsl:text disable-output-escaping="yes">
						&lt;/FRAME&gt;
					</xsl:text>
				</FRAMESET>
				<NOFRAMES>
					<BODY>
						<H2>Frame Alert</H2>
						<P>
							This document is designed to be viewed using
							the frames feature. If you see this message,
							you are using a non-frame-capable web
							client.
						</P>
					</BODY>
				</NOFRAMES>
			</HTML>
		</redirect:write>

		<redirect:write select="$overallOutputPath" method="html">
			<HTML>
				<head>
					<xsl:apply-templates select="." mode="docHeader">
					</xsl:apply-templates>
				</head>

				<BODY>
					<span class="FrameHeadingFont">All Components</span>
					<br />
					<xsl:apply-templates select="." mode="overall">
						<xsl:with-param name="schemaLocation"
							select="$decodedXMLSchemaLocation" />
						<xsl:with-param name="baseDir"
							select="xalan:nodeset($baseInputDir)" />
					</xsl:apply-templates>
				</BODY>
			</HTML>
		</redirect:write>
	</xsl:template>

	<xsl:template match="xs:schema" mode="docHeader">
		<!-- The style is in-lined here so that the generated HTML doc -->
		<!-- does not have to link to our stylesheet. You can replace  -->
		<!-- these style attributes with your own colors or fonts                   -->
		<style type="text/css">
			<![CDATA[
               .src-attribute { font-family: Arial; font-size: 8pt; color: #FF0000; }
               .src-element { font-family: Arial; font-size: 8pt; color: #800000; }                                                                   
               .tableHeader  { font-family: Arial; font-size: 10pt; color: #000000; }
               .tableHeader2 { font-family: Arial; font-size: 11pt; font-weight: bold; color: #000000; }                   
               <!-- .headings     { font-family: Arial; font-size: 10pt; font-weight: bold; color: #6633CC; }    -->
               .headings     { font-family: Arial; font-size: 10pt; font-weight: bold; color: #000000; }
               .smallHeaderFont { font-family: Arial; font-size: 8pt; color: #000000; }
              
               .body { background-color: #FFFFFF }
               .TableHeadingColor     { background: #00CCCC } /* medium aqua */
               .TableSubHeadingColor  { background: #CCFFFF } /* light aqua */
               .TableRowColor         { background: #FFFFFF } /* white */
               .FrameTitleFont   { font-size: normal; font-family: normal }
               .FrameHeadingFont  { font-family: Arial; font-size: 12pt; font-weight: bold; color: #000000; }
               .FrameItemFont    { font-size: normal; font-family: normal }
               
               pre { margin-bottom: 0 }             
                ]]>
		</style>

	</xsl:template>


	<xsl:template match="xs:schema" mode="docBodyOverview">
		<xsl:param name="schemaLocation" />
		<xsl:param name="baseDir" />
		<xsl:param name="fileType" />
		<xsl:param name="usedBySchemas" />

		<xsl:variable name="ns">
			<xsl:apply-templates select="." mode="targetNamespace" />
		</xsl:variable>

		<xsl:variable name="header">
			<xsl:choose>
				<xsl:when test="$fileType='import'">
					Imported Schema
				</xsl:when>
				<xsl:when test="$fileType='include'">
					Included Schema
				</xsl:when>
				<xsl:when test="$fileType='redefine'">
					Redefined Schema
				</xsl:when>
				<xsl:otherwise>Schema Location</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="fileName">
			<xsl:call-template name="getFileName">
				<xsl:with-param name="filePath"
					select="$schemaLocation" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="dependencyName">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), '.html')" />
		</xsl:variable>

		<xsl:variable name="dependencyNameDetails">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<xsl:variable name="outputPathDependencyName">
			<xsl:value-of
				select="concat($outputFolder, substring-before($fileName, '.xsd'), '.html')" />
		</xsl:variable>

		<xsl:variable name="outputPathDetails">
			<xsl:value-of
				select="concat($outputFolder, substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<table>
			<tr>
				<td>
					<!-- <span class="headings"><xsl:value-of select="$header"/></span> -->
					<xsl:text disable-output-escaping="yes">
						&lt;a href=&quot;
					</xsl:text>
					<!-- <xsl:value-of select="$schemaLocation" /> -->
					<xsl:value-of select="$dependencyName" />
					<xsl:text disable-output-escaping="yes">
						&quot; TARGET=&quot;listFrame&quot; &gt;
					</xsl:text>
					<xsl:value-of select="$fileName" />
					<xsl:text disable-output-escaping="yes">
						&lt;/a&gt;
					</xsl:text>
				</td>
			</tr>
		</table>


		<table><!--  xml:space="preserve"> -->
			<redirect:write select="$outputPathDependencyName"
				method="html">
				<HTML>
					<head>
						<xsl:apply-templates select="."
							mode="docHeader">
						</xsl:apply-templates>
					</head>

					<BODY>
						<span class="smallHeaderFont">
							<xsl:value-of select="$fileName" />
						</span>
						<br />
						<hr />
						<span class="FrameHeadingFont">Overview</span>
						<br />
						<xsl:text disable-output-escaping="yes">
							&lt;a href=&quot;
						</xsl:text>
						<xsl:value-of select="$dependencyNameDetails" />
						<xsl:text disable-output-escaping="yes">
							#Overview
						</xsl:text>
						<xsl:text disable-output-escaping="yes">
							&quot; TARGET=&quot;detailFrame&quot; &gt;
						</xsl:text>
						Overview
						<xsl:text disable-output-escaping="yes">
							&lt;/a&gt;
						</xsl:text>
						<xsl:apply-templates select="."
							mode="xmlSchemaOverview">
							<xsl:with-param name="dependencyNameDetails"
								select="$dependencyNameDetails" />
						</xsl:apply-templates>
					</BODY>
				</HTML>
			</redirect:write>
		</table>

		<redirect:write select="$outputPathDetails" method="html">
			<HTML>
				<head>
					<xsl:apply-templates select="." mode="docHeader">
					</xsl:apply-templates>
				</head>
				<BODY BGCOLOR="white">
					<FONT id="Overview" size="+1"
						CLASS="FrameHeadingFont">
						Documentation for
						<xsl:value-of select="$fileName" />
					</FONT>
					<p></p>
					<table>
						<tr>
							<td>
								<span class="headings">
									<xsl:value-of select="$header" />
								</span>
							</td>
							<td>
								<xsl:text
									disable-output-escaping="yes">
									&lt;a href=&quot;
								</xsl:text>
								<xsl:value-of select="$schemaLocation" />
								<xsl:text
									disable-output-escaping="yes">
									&quot;&gt;
								</xsl:text>
								<xsl:value-of select="$schemaLocation" />
								<xsl:text
									disable-output-escaping="yes">
									&lt;/a&gt;
								</xsl:text>
							</td>
						</tr>
						<tr>
							<td>
								<span class="headings">
									Target Namespace
								</span>
							</td>
							<td>
								<xsl:value-of select="$ns" />
							</td>
						</tr>
						<xsl:if test="@version">
							<tr>
								<td>
									<span class="headings">
										Version
									</span>
								</td>
								<td>
									<xsl:value-of select="@version" />
								</td>
							</tr>
						</xsl:if>
						<tr>
							<xsl:apply-templates select="xs:annotation"
								mode="annotate" />
						</tr>
					</table>
					<hr />

					<!--      do not include other dependencies' components
						<xsl:apply-templates select="*[self::xs:include or self::xs:import or self::xs:redefine]" >
						<xsl:with-param name="baseDir" select="$baseDir"/>
						<xsl:with-param name="usedBySchemas" select="$usedBySchemas"/>		
						</xsl:apply-templates>
					-->
					<xsl:apply-templates
						select="*[not(self::xs:annotation 
            or self::xs:include or self::xs:import or self::xs:redefine)]" />
				</BODY>
			</HTML>
		</redirect:write>

		<xsl:apply-templates
			select="*[self::xs:include or self::xs:import or self::xs:redefine]"
			mode="xmlSchemaFilesOverview">
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas"
				select="$usedBySchemas" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- ================================================================== -->
	<!--       Include element                                              -->
	<!-- ================================================================== -->
	<xsl:template match="xs:import | xs:include | xs:redefine">
		<xsl:param name="baseDir" select="." />
		<xsl:param name="usedBySchemas" />

		<xsl:variable name="schema"
			select="document(@schemaLocation, $baseDir)/xs:schema" />

		<xsl:variable name="schemaFileLocation">
			<xsl:choose>
				<xsl:when test="contains(@schemaLocation, ':')">
					<xsl:value-of select="@schemaLocation" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat($baseDir, @schemaLocation)" />
					<!-- globalBaseDir? -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>


		<xsl:choose>
			<xsl:when
				test="contains($usedBySchemas, $schemaFileLocation)">
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="newBaseDir">
					<xsl:call-template name="getBaseDirectory">
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$baseDir" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="newUsedBySchemas">
					<xsl:value-of
						select="concat($usedBySchemas, ':', $schemaFileLocation)" />
				</xsl:variable>

				<xsl:apply-templates select="$schema" mode="docBody">
					<xsl:with-param name="schemaLocation"
						select="$schemaFileLocation" />
					<xsl:with-param name="baseDir" select="$newBaseDir" />
					<xsl:with-param name="usedBySchemas"
						select="$newUsedBySchemas" />
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="xs:import | xs:include | xs:redefine"
		mode="xmlSchemaFilesOverview">
		<xsl:param name="baseDir" select="." />
		<xsl:param name="usedBySchemas" />

		<xsl:variable name="schemaFileLocation">
			<xsl:choose>
				<xsl:when test="contains(@schemaLocation, ':')">
					<xsl:value-of select="@schemaLocation" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat($globalBaseDir, @schemaLocation)" />
					<!-- changed from baseDir -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="schema"
			select="document(@schemaLocation, document($schemaFileLocation))/xs:schema" />

		<xsl:choose>
			<xsl:when
				test="contains($usedBySchemas, $schemaFileLocation)">
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="newBaseDir">
					<xsl:call-template name="getBaseDirectory">
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$baseDir" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="newUsedBySchemas">
					<xsl:value-of
						select="concat($usedBySchemas, ':', $schemaFileLocation)" />
				</xsl:variable>

				<xsl:apply-templates select="$schema"
					mode="docBodyOverview">
					<xsl:with-param name="schemaLocation"
						select="$schemaFileLocation" />
					<xsl:with-param name="baseDir" select="$newBaseDir" />
					<xsl:with-param name="fileType"
						select="local-name(.)" />
					<xsl:with-param name="usedBySchemas"
						select="$newUsedBySchemas" />
				</xsl:apply-templates>

			</xsl:otherwise>

		</xsl:choose>


	</xsl:template>

	<xsl:template match="xs:schema" mode="docBody">
		<xsl:param name="baseDir" />
		<xsl:param name="usedBySchemas" />

		<xsl:apply-templates
			select="*[self::xs:include or self::xs:import or self::xs:redefine]">
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas"
				select="$usedBySchemas" />
		</xsl:apply-templates>

		<xsl:apply-templates
			select="*[not(self::xs:annotation 
                     or self::xs:include or self::xs:import or self::xs:redefine)]" />
	</xsl:template>



	<!-- ====================================================================== -->
	<!--    This is a helper template to generate some overview links           -->
	<!-- ====================================================================== -->
	<xsl:template match="xs:schema" mode="xmlSchemaOverview">
		<xsl:param name="dependencyNameDetails" />
		<xsl:if test="count(./xs:element)> 0">
			<p />
			<span class="FrameHeadingFont">Elements</span>
			<br />
			<xsl:apply-templates select="./xs:element"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>

		<xsl:if test="count(./xs:complexType)>0">
			<p />
			<span class="FrameHeadingFont">Complex Types</span>
			<br />
			<xsl:apply-templates select="./xs:complexType"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>

		<xsl:if test="count(./xs:simpleType)>0">
			<p />
			<span class="FrameHeadingFont">Simple Types</span>
			<br />
			<xsl:apply-templates select="./xs:simpleType"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>

		<xsl:if test="count(./xs:attributeGroup)>0">
			<p />
			<span class="FrameHeadingFont">Attribute Groups</span>
			<br />
			<xsl:apply-templates select="./xs:attributeGroup"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>

		<xsl:if test="count(./xs:attribute)>0">
			<p />
			<span class="FrameHeadingFont">Attributes</span>
			<br />
			<xsl:apply-templates select="./xs:attribute"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>

		<xsl:if test="count(./xs:group)>0">
			<p />
			<span class="FrameHeadingFont">Groups</span>
			<br />
			<xsl:apply-templates select="./xs:group"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>

		<xsl:if test="count(./xs:notation)>0">
			<p />
			<span class="FrameHeadingFont">Notation</span>
			<br />
			<xsl:apply-templates select="./xs:notation"
				mode="xmlSchemaOverview">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
				<xsl:sort select="@name" />
			</xsl:apply-templates>
		</xsl:if>


	</xsl:template>

	<xsl:template
		match="xs:element | xs:complexType | xs:simpleType | xs:attributeGroup |
                    xs:attribute | xs:group | xs:notation"
		mode="xmlSchemaOverview">
		<xsl:param name="dependencyNameDetails" />
		<xsl:variable name="id">
			<xsl:apply-templates select="." mode="id">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
			</xsl:apply-templates>
		</xsl:variable>
		<xsl:text disable-output-escaping="yes">
			&lt;a href=&quot;
		</xsl:text>
		<xsl:value-of select="$dependencyNameDetails" />
		<xsl:text disable-output-escaping="yes">#</xsl:text>
		<xsl:value-of select="$id" />
		<xsl:text disable-output-escaping="yes">
			&quot; TARGET=&quot;detailFrame&quot; &gt;
		</xsl:text>
		<xsl:value-of select="@name" />
		<xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
		<br />
	</xsl:template>


	<!-- ================================================================== -->
	<!--      Create a new heading for each element                         -->
	<!-- ================================================================== -->
	<xsl:template match="xs:element">
		<div class="element">
			<xsl:variable name="id">
				<xsl:apply-templates select="." mode="id" />
			</xsl:variable>

			<!-- ======== Create the heading for this table ======= -->
			<xsl:variable name="parent" select="local-name(..)" />

			<xsl:choose>
				<xsl:when test="$parent != 'schema'">
					<!-- This is a local element and it is not ref -->
					<xsl:if test="not(@ref)">
						<xsl:variable name="complex-type">
							<xsl:apply-templates select=".."
								mode="findParent" />
						</xsl:variable>

						<h3 id="{$id}">
							<span class="tableHeader">element</span>
							<span class="tableHeader2">
								<xsl:value-of select="$complex-type" />
								<xsl:text>/</xsl:text>
								<xsl:value-of select="@name" />
							</span>
						</h3>
						<xsl:apply-templates select="."
							mode="createTable" />
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<h3 id="{$id}">
						<span class="tableHeader">element</span>
						<span class="tableHeader2">
							<xsl:value-of select="@name" />
						</span>
					</h3>
					<xsl:apply-templates select="." mode="createTable" />
				</xsl:otherwise>
			</xsl:choose>

			<!-- Create the new element headings for those elements that -->
			<!-- belong to the anonymous type -->
			<xsl:apply-templates
				select="xs:complexType/*[not(self::xs:annotation)]" />
		</div>
	</xsl:template>

	<!-- ================================================================== -->
	<!--     Create the HTML table for this element                         -->
	<!-- ================================================================== -->
	<xsl:template match="xs:element" mode="createTable">
		<table width="100%" cellspacing="0" cellpadding="5"
			border="1">
			<xsl:apply-templates select="xs:annotation" mode="annotate" />
			<xsl:variable name="ns">
				<xsl:apply-templates select="." mode="targetNamespace" />
			</xsl:variable>

			<xsl:choose>
				<xsl:when test="$ns">
					<tr>
						<td width="10%">
							<span class="headings">Namespace</span>
						</td>
						<!--td width="90%"><xsl:value-of select="$targetNamespace"/></td-->
						<td width="90%">
							<xsl:value-of select="$ns" />
						</td>

					</tr>
				</xsl:when>

			</xsl:choose>

			<xsl:choose>
				<xsl:when test="@type">
					<xsl:apply-templates select="@type" />
				</xsl:when>
				<xsl:otherwise>
					<!-- Type is not defined.         -->
					<!-- Process those anonymous type -->
					<xsl:apply-templates select="xs:complexType" />
				</xsl:otherwise>
			</xsl:choose>

			<xsl:apply-templates select="@substitutionGroup" />
			<tr>
				<xsl:if test="not(@ref)">
					<td width="10%">
						<span class="headings">Source</span>
					</td>
					<td width="90%">
						<xsl:apply-templates select="." mode="source" />
					</td>
				</xsl:if>
			</tr>

		</table>
	</xsl:template>

	<!-- ================================================================== -->
	<!--    Find the target namespace for this global element               -->
	<!-- ================================================================== -->
	<xsl:template match="xs:element" mode="targetNamespace">
		<xsl:variable name="targetNamespace"
			select="ancestor::xs:schema/@targetNamespace">
		</xsl:variable>
		<xsl:choose>
			<xsl:when
				test="$targetNamespace and 
                      (parent::xs:schema or
                       @form = 'qualified' or
                       ancestor::xs:schema/@elementFormDefault = 'qualified')">
				<xsl:value-of select="$targetNamespace" />

			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- ================================================================== -->
	<!--   Process a local element (element name and element ref)           -->
	<!-- ================================================================== -->
	<xsl:template match="xs:element" mode="model">
		<xsl:variable name="id">
			<xsl:apply-templates select="." mode="id" />
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="@ref">
				<xsl:apply-templates select="." mode="link">
					<xsl:with-param name="qname" select="@ref" />
					<xsl:with-param name="type"
						select="'elementDeclarations'" />
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text disable-output-escaping="yes">
					&lt;a href=&quot;#
				</xsl:text>
				<xsl:value-of select="$id" />
				<xsl:text disable-output-escaping="yes">
					&quot;&gt;
				</xsl:text>
				<xsl:value-of select="@name" />
				<xsl:text disable-output-escaping="yes">
					&lt;/a&gt;
				</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="." mode="occurs" />
		<br />
	</xsl:template>

	<!-- ================================================================== -->
	<!--          Handles substitution group reference                      -->
	<!-- ================================================================== -->
	<xsl:template match="@substitutionGroup">
		<tr>
			<td>
				<span class="headings">Substitution Group</span>
			</td>
			<td>
				<xsl:apply-templates select=".." mode="link">
					<xsl:with-param name="qname" select="." />
					<xsl:with-param name="type"
						select="'elementDeclarations'" />
				</xsl:apply-templates>
			</td>
		</tr>
	</xsl:template>


	<!-- ================================================================== -->
	<!--                    Simple Type                                     -->
	<!-- ================================================================== -->
	<xsl:template match="xs:simpleType">
		<xsl:variable name="schema" select="ancestor::xs:schema" />
		<xsl:variable name="id">
			<xsl:apply-templates select="." mode="id" />
		</xsl:variable>
		<div class="simpleType">
			<h3 id="{$id}">
				<span class="tableHeader">simple type</span>
				<span class="tableHeader2">
					<xsl:value-of select="@name" />
				</span>
			</h3>
			<table width="100%" cellspacing="0" cellpadding="5"
				border="1">
				<xsl:apply-templates select="xs:annotation"
					mode="annotate" />
				<tr>
					<td width="10%">
						<span class="headings">Namespace</span>
					</td>
					<td width="90%">
						<xsl:apply-templates select="."
							mode="targetNamespace" />
					</td>
				</tr>
				<xsl:apply-templates
					select="*[not(self::xs:annotation)]" />
				<xsl:apply-templates select="." mode="source" />
			</table>
		</div>
	</xsl:template>

	<!-- ================================================================== -->
	<!--    Handle simple type - list case                                  -->
	<!-- ================================================================== -->
	<xsl:template match="xs:simpleType/xs:list">
		<tr>
			<td>
				<span class="headings">Type</span>
			</td>
			<td>
				<xsl:apply-templates select="xs:annotation"
					mode="annotate" />
				<xsl:choose>
					<xsl:when test="@itemType">
						<xsl:text>list of</xsl:text>
						<xsl:apply-templates select="." mode="link">
							<xsl:with-param name="qname"
								select="@itemType" />
						</xsl:apply-templates>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="xs:simpleType" />
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>

	<!-- ================================================================== -->
	<!--    Handle simple type - union case                                 -->
	<!-- ================================================================== -->
	<xsl:template match="xs:simpleType/xs:union">
		<tr>
			<td>
				<span class="headings">Type</span>
			</td>
			<td>
				<xsl:apply-templates select="xs:annotation"
					mode="annotate" />
				<xsl:text>union of</xsl:text>
				<xsl:apply-templates select="." mode="link">
					<xsl:with-param name="qname" select="@memberTypes" />
				</xsl:apply-templates>
			</td>
		</tr>
	</xsl:template>

	<!-- ================================================================== -->
	<!--    Handle simple type - restriction case                           -->
	<!-- ================================================================== -->
	<xsl:template match="xs:simpleType/xs:restriction">
		<tr>
			<td>
				<span class="headings">Type</span>
			</td>
			<td>
				<xsl:text>restriction of</xsl:text>
				<xsl:apply-templates select="." mode="link">
					<xsl:with-param name="qname" select="@base" />
				</xsl:apply-templates>
			</td>
		</tr>
		<tr>
			<td>
				<span class="headings">Facets</span>
			</td>
			<td>
				<xsl:apply-templates select="xs:annotation"
					mode="annotate" />
				<xsl:for-each select="node()">
					<xsl:value-of select="name()" />
					<xsl:text>=</xsl:text>
					<xsl:value-of select="@value" />
					<br />
				</xsl:for-each>
			</td>
		</tr>
	</xsl:template>


	<!-- ================================================================== -->
	<!--                         Complex Type                               -->
	<!-- ================================================================== -->
	<xsl:template match="xs:complexType">
		<xsl:variable name="id">
			<xsl:apply-templates select="." mode="id" />
		</xsl:variable>

		<xsl:variable name="parent" select="local-name(..)" />

		<xsl:choose>
			<xsl:when test="$parent = 'schema'">
				<div class="complexType">
					<h3 id="{$id}">
						<span class="tableHeader">complex type</span>
						<span class="tableHeader2">
							<xsl:value-of select="@name" />
						</span>
					</h3>
					<table width="100%" cellspacing="0" cellpadding="5"
						border="1">
						<xsl:apply-templates select="xs:annotation"
							mode="annotate" />
						<tr>
							<td width="10%">
								<span class="headings">Namespace</span>
							</td>
							<td width="90%">
								<xsl:apply-templates select="."
									mode="targetNamespace" />
							</td>
						</tr>

						<xsl:choose>
							<xsl:when
								test="xs:simpleContent | xs:complexContent">
								<tr>
									<td>
										<span class="headings">
											Type
										</span>
									</td>
									<td>
										<xsl:value-of
											select="local-name((xs:simpleContent | xs:complexContent)/*[not(self::xs:annotation)])" />
										<xsl:variable name="derivation"
											select="(xs:simpleContent | xs:complexContent)/*[not(self::xs:annotation)]" />
										<xsl:text>of</xsl:text>
										<xsl:apply-templates
											select="$derivation" mode="link">
											<xsl:with-param name="qname"
												select="$derivation/@base" />
										</xsl:apply-templates>
										<xsl:text></xsl:text>
										<!-- Process the simpleContent or complexContent -->
										<!-- extension/restriction element               -->
										<xsl:apply-templates
											select="*[not(self::xs:annotation)]" mode="model" />
									</td>
								</tr>
							</xsl:when>
						</xsl:choose>

						<xsl:apply-templates select="."
							mode="attributes" />
						<xsl:apply-templates select="." mode="content" />
						<xsl:apply-templates select="." mode="source" />
					</table>

					<!--  Generate each element in the complex type as a new heading  -->
					<!--  Also handles anonymous type                                 -->
					<xsl:apply-templates
						select="*[not(self::xs:annotation)]" />
				</div>
			</xsl:when>
			<xsl:otherwise>
				<!-- annonymous complex type -->
				<xsl:apply-templates select="." mode="attributes" />
				<xsl:apply-templates select="." mode="content" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- ================================================================== -->
	<!--           Complex Type content                                     -->
	<!-- ================================================================== -->
	<xsl:template match="xs:complexType" mode="content">
		<xsl:variable name="model"
			select="xs:all | xs:sequence | xs:choice | xs:group" />
		<xsl:variable name="contentType" select="local-name($model)" />
		<xsl:if test="$model">
			<xsl:apply-templates select="$model" mode="model" />
		</xsl:if>
	</xsl:template>

	<!-- ====================================================================== -->
	<!--   Handle the complexType extension or restriction element for          -->
	<!--   a simpleContent or complexContent.                                   -->
	<!--   Process its content and annotation only                           -->
	<!-- ====================================================================== -->
	<xsl:template match="xs:extension | xs:restriction" mode="model">
		<xsl:apply-templates select="xs:annotation" mode="annotate" />
		<xsl:apply-templates
			select="xs:all | xs:sequence | xs:choice | xs:group" mode="model" />
	</xsl:template>

	<!-- ================================================================== -->
	<!--   Process Complex Type and Attribute Group - Attributes            -->
	<!--     Calls the xs:attribute (mode=attributes) template              -->
	<!-- ================================================================== -->
	<xsl:template match="xs:complexType | xs:attributeGroup"
		mode="attributes">
		<xsl:variable name="attributes">
			<xsl:apply-templates select="*[not(self::xs:annotation)]"
				mode="anAttribute" />
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="string($attributes)">
				<tr>
					<td>
						<span class="headings">Attributes</span>
					</td>
					<td>
						<table cellspacing="0" cellpadding="0">
							<tr>
								<td width="20%" align="left">
									<span class="headings">Name</span>
								</td>
								<td width="20%" align="left">
									<span class="headings">Type</span>
								</td>
								<td width="20%" align="left">
									<span class="headings">Use</span>
								</td>
								<td width="20%" align="left">
									<span class="headings">
										Default
									</span>
								</td>
								<td width="20%" align="left">
									<span class="headings">Fixed</span>
								</td>
								<td width="20%" align="left">
									<span class="headings">Form</span>
								</td>
							</tr>
							<xsl:copy-of select="$attributes" />
						</table>
					</td>
				</tr>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- ============================================================== -->
	<!--       Process global attribute                                 -->
	<!-- ============================================================== -->
	<xsl:template match="xs:attribute">
		<xsl:variable name="parent" select="local-name(..)" />
		<xsl:if test="$parent = 'schema'">
			<div class="attribute">
				<xsl:variable name="id">
					<xsl:apply-templates select="." mode="id" />
				</xsl:variable>

				<h3 id="{$id}">
					<span class="tableHeader">attribute</span>
					<span class="tableHeader2">
						<xsl:value-of select="@name" />
					</span>
				</h3>

				<table width="100%" cellspacing="0" cellpadding="5"
					border="1">
					<xsl:apply-templates select="xs:annotation"
						mode="annotate" />
					<xsl:apply-templates select="."
						mode="targetNamespace" />
					<xsl:apply-templates select="@type" />
					<tr>
						<td width="10%">
							<span class="headings">Source</span>
						</td>
						<td width="90%">
							<xsl:apply-templates select="."
								mode="source" />
						</td>
					</tr>
				</table>
			</div>
		</xsl:if>
	</xsl:template>

	<!-- ============================================================== -->
	<!--       Process global attribute namespace                       -->
	<!--        										                -->
	<!-- ============================================================== -->
	<xsl:template match="xs:attribute" mode="targetNamespace">
		<xsl:variable name="targetNamespace"
			select="ancestor::xs:schema/@targetNamespace">
		</xsl:variable>

		<xsl:choose>
			<xsl:when
				test="$targetNamespace and 
                      (parent::xs:schema or
                       @form = 'qualified' or
                       ancestor::xs:schema/@attributeFormDefault = 'qualified')">
				<tr>
					<td>
						<span class="headings">Namespace</span>
					</td>
					<td>
						<xsl:value-of select="$targetNamespace" />
					</td>
				</tr>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- ============================================================== -->
	<!--   Process a local attribute name/ref or an attributeGroup ref  -->
	<!--     Called by template matching:                               -->
	<!--         - xs:complexType                                       -->
	<!--         - xs:attributeGroup                                    -->
	<!--         - xs:extension or xs:restriction                       -->
	<!-- ============================================================== -->
	<xsl:template match="xs:attribute | xs:attributeGroup"
		mode="anAttribute">
		<xsl:variable name="use">
			<xsl:choose>
				<xsl:when test="@use = 'required'">required</xsl:when>
				<xsl:when test="@use = 'prohibited'">
					prohibited
				</xsl:when>
				<xsl:otherwise>optional</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<tr class="attribute">
			<xsl:choose>
				<xsl:when test="local-name() = 'attributeGroup'">
					<td>
						<xsl:apply-templates select="." mode="link">
							<xsl:with-param name="qname" select="@ref" />
							<xsl:with-param name="type"
								select="'attributeGroupDefinitions'" />
						</xsl:apply-templates>
					</td>
				</xsl:when>
				<xsl:when test="@ref">
					<td>
						<xsl:apply-templates select="." mode="link">
							<xsl:with-param name="qname" select="@ref" />
							<xsl:with-param name="type"
								select="'attributeDeclarations'" />
						</xsl:apply-templates>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td>
						<xsl:value-of select="@name" />
					</td>
					<td>
						<xsl:apply-templates select="." mode="link">
							<xsl:with-param name="qname" select="@type" />
						</xsl:apply-templates>
					</td>
				</xsl:otherwise>
			</xsl:choose>
			<td>
				<xsl:value-of select="@use" />
			</td>
			<td>
				<xsl:value-of select="@default" />
			</td>
			<td>
				<xsl:value-of select="@fixed" />
			</td>
			<td>
				<xsl:value-of select="@form" />
			</td>
		</tr>
	</xsl:template>

	<!-- ================================================================== -->
	<!--           Process an any attribute                                 -->
	<!-- ================================================================== -->
	<xsl:template match="xs:anyAttribute" mode="anAttribute">
		<tr class="attribute">
			<td>anyAttribute</td>
		</tr>
	</xsl:template>

	<!-- ================================================================== -->
	<!--           Attribute Group                                          -->
	<!-- ================================================================== -->
	<xsl:template match="xs:attributeGroup">
		<xsl:variable name="parent" select="local-name(..)" />
		<xsl:if test="$parent = 'schema'">
			<xsl:variable name="id">
				<xsl:apply-templates select="." mode="id" />
			</xsl:variable>
			<div class="attributeGroup">
				<h3 id="{$id}">
					<span class="tableHeader">attribute group</span>
					<span class="tableHeader2">
						<xsl:value-of select="@name" />
					</span>
				</h3>
				<table width="100%" cellspacing="0" cellpadding="5"
					border="1">
					<xsl:apply-templates select="xs:annotation"
						mode="annotate" />
					<tr>
						<td width="10%">
							<span class="headings">Namespace</span>
						</td>
						<td width="90%">
							<xsl:apply-templates select="."
								mode="targetNamespace" />
						</td>
					</tr>

					<!-- Process the attributes in the attribute group -->
					<xsl:apply-templates select="." mode="attributes" />
					<xsl:apply-templates select="." mode="source" />
				</table>
			</div>
		</xsl:if>
	</xsl:template>

	<!-- ====================================================================== -->
	<!--    Handle content model for <sequence>, <choice> or <all>              -->
	<!-- ====================================================================== -->
	<xsl:template match="xs:all | xs:sequence | xs:choice"
		mode="model">

		<xsl:apply-templates select="xs:annotation" mode="annotate" />
		<tr>
			<td>
				<span class="headings">
					<xsl:text>Content</xsl:text>
					<br />
					<xsl:value-of select="local-name()" />
					<xsl:apply-templates select="." mode="occurs" />
				</span>
			</td>
			<td>
				<xsl:for-each select="*[not(self::xs:annotation)]">
					<xsl:variable name="construct"
						select="local-name()" />
					<xsl:choose>
						<xsl:when
							test="$construct = 'all' or $construct = 'sequence' or
                           $construct = 'choice'">
							<xsl:apply-templates
								select="*[not(self::xs:annotation)]" mode="model" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates select="."
								mode="model" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</td>
		</tr>
	</xsl:template>

	<!-- ================================================================== -->
	<!--           Group                                                    -->
	<!-- ================================================================== -->
	<xsl:template match="xs:group">
		<xsl:variable name="parent" select="local-name(..)" />
		<xsl:if test="$parent = 'schema'">
			<xsl:variable name="id">
				<xsl:apply-templates select="." mode="id" />
			</xsl:variable>
			<div class="group">
				<h3 id="{$id}">
					<span class="tableHeader">group</span>
					<span class="tableHeader2">
						<xsl:value-of select="@name" />
					</span>
				</h3>
				<table width="100%" cellspacing="0" cellpadding="5"
					border="1">
					<xsl:apply-templates select="xs:annotation"
						mode="annotate" />
					<tr>
						<td width="10%">
							<span class="headings">Namespace</span>
						</td>
						<td width="90%">
							<xsl:apply-templates select="."
								mode="targetNamespace" />
						</td>
					</tr>

					<!-- Process the content for group -->
					<xsl:apply-templates
						select="*[not(self::xs:annotation)]" mode="model" />
					<xsl:apply-templates select="." mode="source" />
				</table>

				<!--  Generate each element in the group as a new heading  -->
				<xsl:apply-templates
					select="*[not(self::xs:annotation)]" />
			</div>
		</xsl:if>
	</xsl:template>

	<!-- ================================================================== -->
	<!--           Process Group Ref                                        -->
	<!-- ================================================================== -->
	<xsl:template match="xs:group" mode="model">
		<xsl:choose>
			<xsl:when test="@ref">
				<xsl:apply-templates select="." mode="link">
					<xsl:with-param name="qname" select="@ref" />
					<xsl:with-param name="type"
						select="'groupDefinitions'" />
				</xsl:apply-templates>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates select="." mode="occurs" />
		<br />
	</xsl:template>

	<!-- ================================================================== -->
	<!--           Process any                                              -->
	<!-- ================================================================== -->
	<xsl:template match="xs:any" mode="model">
		<xsl:text>any</xsl:text>
		<xsl:apply-templates select="." mode="occurs" />
		<br />
	</xsl:template>

	<!-- ====================================================================== -->
	<!--    This template handles those annotations that are explicitly         -->
	<!--    asked for                                                           -->
	<!-- ====================================================================== -->
	<xsl:template match="xs:annotation" mode="annotate">
		<xsl:if test="xs:documentation">
			<tr>
				<td>
					<span class="headings">Documentation</span>
				</td>
				<td>
					<xsl:apply-templates select="xs:documentation"
						mode="annotate" />
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="xs:appinfo">
			<tr>
				<td>
					<span class="headings">
						Application Information
					</span>
				</td>
				<td>
					<xsl:apply-templates select="xs:appinfo"
						mode="annotate" />
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<xsl:template match="xs:documentation | xs:appinfo"
		mode="annotate">
		<p>
			<xsl:apply-templates />
		</p>
	</xsl:template>

	<!-- ====================================================================== -->
	<!--    Process namespace                                                   -->
	<!-- ====================================================================== -->
	<xsl:template match="xs:import" mode="targetNamespace">
		<xsl:variable name="ns">
			<xsl:value-of select="@namespace" />
			<xsl:if test="not(@namespace)">no namespace</xsl:if>
		</xsl:variable>
		<xsl:value-of select="$ns" />
	</xsl:template>


	<xsl:template match="xs:schema" mode="targetNamespace">
		<xsl:variable name="ns">
			<xsl:value-of select="@targetNamespace" />
			<xsl:if test="not(@targetNamespace)">no namespace</xsl:if>
		</xsl:variable>
		<xsl:value-of select="$ns" />
	</xsl:template>

	<xsl:template match="*" mode="targetNamespace">
		<xsl:choose>
			<xsl:when test="ancestor::xs:schema/@targetNamespace">
				<xsl:value-of
					select="ancestor::xs:schema/@targetNamespace" />
			</xsl:when>
		</xsl:choose>
	</xsl:template>



	<!-- ===================================================================== -->
	<!--                        Type Definition                                -->
	<!-- ===================================================================== -->
	<xsl:template match="@type">
		<tr>
			<td width="10%">
				<span class="headings">Type</span>
			</td>
			<td width="90%">
				<xsl:apply-templates select=".." mode="link">
					<xsl:with-param name="qname" select="." />
				</xsl:apply-templates>
			</td>
		</tr>
	</xsl:template>

	<xsl:template
		match="xs:redefine/xs:complexType/*/xs:extension | 
                     xs:redefine/xs:complexType/*/xs:restriction |
                     xs:redefine/xs:simpleType/xs:restriction |
                     xs:redefine/xs:group//xs:group[@ref = ancestor::xs:group[parent::xs:redefine]/@name or
                                                    substring-after(@ref, ':') = ancestor::xs:group[parent::xs:redefine]/@name] |
                     xs:redefine/xs:attributeGroup/xs:attributeGroup[@ref = ../@name or 
                                                                     substring-after(@ref, ':') = ../@name]"
		mode="link">
		<xsl:param name="qname" />
		<xsl:param name="type" select="'typeDefinitions'" />
		<xsl:variable name="name">
			<xsl:apply-templates select="." mode="resolve">
				<xsl:with-param name="qname" select="$qname" />
			</xsl:apply-templates>
		</xsl:variable>
		<xsl:variable name="id">
			<xsl:apply-templates select="ancestor::xs:redefine"
				mode="getID">
				<xsl:with-param name="ns"
					select="substring-before(substring($name, 2), '}')" />
				<xsl:with-param name="localName"
					select="substring-after($name, '}')" />
				<xsl:with-param name="type" select="$type" />
			</xsl:apply-templates>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="string($id)">
				<a href="#{$id}">
					<xsl:value-of select="$qname" />
				</a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$qname" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:variable name="schema" select="/xs:schema" />


	<xsl:template match="xs:schema" mode="getID">
		<xsl:param name="ns" />
		<xsl:param name="localName" />
		<xsl:param name="type" select="'typeDefinitions'" />
		<xsl:param name="targetNS" select="@targetNamespace" />
		<xsl:param name="schemaLocation"
			select="$decodedXMLSchemaLocation" />
		<xsl:param name="baseDir" select="xalan:nodeset($baseInputDir)" />
		<xsl:param name="usedBySchemas" />

		<xsl:variable name="id">
			<xsl:if
				test="($targetNS = $ns) or (string-length($targetNS) = 0 and string-length($ns) = 0)">
				<xsl:apply-templates
					select="key($type, concat('{', @targetNamespace, '}', $localName))"
					mode="id">
				</xsl:apply-templates>
			</xsl:if>
		</xsl:variable>

		<xsl:variable name="fileName">
			<xsl:call-template name="getFileName">
				<xsl:with-param name="filePath"
					select="$schemaLocation" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="dependencyNameDetails">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="string($id)">
				<xsl:value-of
					select="concat($dependencyNameDetails, '#', $id)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates
					select="(xs:include | xs:redefine | xs:import)[1]" mode="getID">
					<xsl:with-param name="ns" select="$ns" />
					<xsl:with-param name="localName"
						select="$localName" />
					<xsl:with-param name="type" select="$type" />
					<xsl:with-param name="targetNS" select="$targetNS" />
					<xsl:with-param name="baseDir" select="$baseDir" />
					<xsl:with-param name="usedBySchemas"
						select="$usedBySchemas" />

				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="xs:import" mode="getID">
		<xsl:param name="ns" />
		<xsl:param name="localName" />
		<xsl:param name="type" select="'typeDefinitions'" />
		<xsl:param name="targetNS" select="@namespace" />
		<xsl:param name="baseDir" select="xalan:nodeset($baseInputDir)" />
		<xsl:param name="usedBySchemas" />


		<xsl:variable name="schemaFileLocation">
			<xsl:choose>
				<xsl:when test="contains(@schemaLocation, ':')">
					<xsl:value-of select="@schemaLocation" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat($baseDir, @schemaLocation)" />
					<!-- globalBaseDir? -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>


		<xsl:choose>
			<xsl:when
				test="contains($usedBySchemas, $schemaFileLocation)">
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="newBaseDir">
					<xsl:call-template name="getBaseDirectory">
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$baseDir" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="newUsedBySchemas">
					<xsl:value-of
						select="concat($usedBySchemas, ':', $schemaFileLocation)" />
				</xsl:variable>

				<xsl:variable name="id">
					<xsl:apply-templates
						select="document(@schemaLocation, document($schemaFileLocation))/xs:schema"
						mode="getID">
						<xsl:with-param name="ns" select="$ns" />
						<xsl:with-param name="localName"
							select="$localName" />
						<xsl:with-param name="type" select="$type" />
						<xsl:with-param name="targetNS"
							select="@namespace" />
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$newBaseDir" />
						<xsl:with-param name="usedBySchemas"
							select="$newUsedBySchemas" />
					</xsl:apply-templates>
				</xsl:variable>

				<xsl:choose>
					<xsl:when test="string($id)">
						<xsl:value-of select="$id" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates
							select="following-sibling::*[self::xs:include or self::xs:redefine or self::import][1]"
							mode="getID">
							<xsl:with-param name="ns" select="$ns" />
							<xsl:with-param name="localName"
								select="$localName" />
							<xsl:with-param name="type" select="$type" />
							<xsl:with-param name="targetNS"
								select="$targetNS" />
							<xsl:with-param name="baseDir"
								select="$baseDir" />
							<xsl:with-param name="usedBySchemas"
								select="$usedBySchemas" />
						</xsl:apply-templates>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template match="xs:include | xs:redefine" mode="getID">
		<xsl:param name="ns" />
		<xsl:param name="localName" />
		<xsl:param name="type" select="'typeDefinitions'" />
		<xsl:param name="targetNS"
			select="ancestor::xs:schema/@targetNamespace" />
		<xsl:param name="baseDir" select="xalan:nodeset($baseInputDir)" />
		<xsl:param name="usedBySchemas" />

		<xsl:variable name="schemaFileLocation">
			<xsl:choose>
				<xsl:when test="contains(@schemaLocation, ':')">
					<xsl:value-of select="@schemaLocation" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat($baseDir, @schemaLocation)" />
					<!-- globalBaseDir? -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when
				test="contains($usedBySchemas, $schemaFileLocation)">
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="newBaseDir">
					<xsl:call-template name="getBaseDirectory">
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$baseDir" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="newUsedBySchemas">
					<xsl:value-of
						select="concat($usedBySchemas, ':', $schemaFileLocation)" />
				</xsl:variable>

				<xsl:variable name="id">
					<xsl:apply-templates
						select="document(@schemaLocation, document($schemaFileLocation))/xs:schema"
						mode="getID">
						<xsl:with-param name="ns" select="$ns" />
						<xsl:with-param name="localName"
							select="$localName" />
						<xsl:with-param name="type" select="$type" />
						<xsl:with-param name="targetNS"
							select="$targetNS" />
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$newBaseDir" />
						<xsl:with-param name="usedBySchemas"
							select="$newUsedBySchemas" />
					</xsl:apply-templates>
				</xsl:variable>

				<xsl:choose>
					<xsl:when test="string($id)">
						<xsl:value-of select="$id" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates
							select="following-sibling::*[self::xs:include or self::xs:redefine or self::import][1]"
							mode="getID">
							<xsl:with-param name="ns" select="$ns" />
							<xsl:with-param name="localName"
								select="$localName" />
							<xsl:with-param name="type" select="$type" />
							<xsl:with-param name="targetNS"
								select="$targetNS" />
							<xsl:with-param name="baseDir"
								select="$baseDir" />
							<xsl:with-param name="usedBySchemas"
								select="$usedBySchemas" />
						</xsl:apply-templates>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- ================================================================== -->
	<!--     Helper template for attributes                                 -->
	<!-- ================================================================== -->
	<xsl:template match="*" mode="attributes" />

	<!-- ================================================================== -->
	<!--     This is a helper template to find the parent's name            -->
	<!--     (e.g. complex type, group) of a local element                  -->
	<!-- ================================================================== -->
	<xsl:template match="*" mode="findParent">
		<xsl:variable name="construct" select="local-name()" />
		<xsl:variable name="parent" select="local-name(..)" />
		<xsl:choose>
			<xsl:when test="$construct = 'complexType' and @name">
				<xsl:value-of select="@name" />
			</xsl:when>

			<xsl:when test="$construct = 'group' and @name">
				<xsl:value-of select="@name" />
			</xsl:when>

			<xsl:when test="$parent = 'schema'">
				<!-- should not reach here, make sure we exit -->
			</xsl:when>

			<xsl:otherwise>
				<xsl:apply-templates select=".." mode="findParent" />
				<xsl:if
					test="$construct = 'complexType' or $construct = 'group' and not(@name)">
					<!-- only add a / if this element is not a global element -->
					<xsl:variable name="parentScope"
						select="local-name(../..)" />
					<xsl:if test="not($parentScope = 'schema')">
						<xsl:text>/</xsl:text>
					</xsl:if>
					<xsl:value-of select="../@name" />
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- ====================================================================== -->
	<!--    This is a helper template to test for minOccurs and maxOccurs       -->
	<!-- ====================================================================== -->
	<xsl:template match="*" mode="occurs">
		<xsl:if test="@minOccurs or @maxOccurs">
			<xsl:text>{</xsl:text>
			<xsl:value-of select="@minOccurs" />
			<xsl:if test="not(@minOccurs)">1</xsl:if>
			<xsl:text>,</xsl:text>
			<xsl:value-of select="@maxOccurs" />
			<xsl:if test="not(@maxOccurs)">1</xsl:if>
			<xsl:text>}</xsl:text>
		</xsl:if>
	</xsl:template>

	<!-- ================================================================== -->
	<!--   This is a helper template to generate a unique id                -->
	<!-- ================================================================== -->
	<xsl:template match="*" mode="id">
		<xsl:param name="dependencyNameDetails" />
		<!--xsl:value-of select="generate-id()" /-->
		<xsl:variable name="targetNS">
			<xsl:apply-templates select="." mode="targetNamespace" />
		</xsl:variable>
		<xsl:variable name="compName">
			<xsl:value-of select="name()" />
		</xsl:variable>

		<xsl:variable name="parent" select="local-name(..)" />

		<xsl:variable name="name">
			<xsl:choose>
				<xsl:when test="$parent != 'schema'">
					<!-- This is a local element and it is not ref -->
					<xsl:if test="not(@ref)">
						<xsl:variable name="complex-type">
							<xsl:apply-templates select=".."
								mode="findParent" />
						</xsl:variable>

						<xsl:if test="string($complex-type)">
							<xsl:value-of select="$complex-type" />
							<xsl:text>/</xsl:text>
						</xsl:if>
						<xsl:value-of select="@name" />
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@name" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="string($targetNS)">
				<xsl:value-of
					select="concat($compName, '{', $targetNS, '}', $name)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="concat($compName, $name)" />
			</xsl:otherwise>
		</xsl:choose>


	</xsl:template>



	<!-- ================================================================== -->
	<!--     This is a helper template to figure out link                   -->
	<!--     using a key function.It calls resolve                          -->
	<!-- ================================================================== -->
	<xsl:template match="*" mode="link">
		<xsl:param name="qname" />
		<xsl:param name="type" select="'typeDefinitions'" />
		<xsl:variable name="name">
			<xsl:apply-templates select="." mode="resolve">
				<xsl:with-param name="qname" select="$qname" />
			</xsl:apply-templates>
		</xsl:variable>


		<xsl:variable name="id">
			<xsl:apply-templates select="$schema" mode="getID">
				<xsl:with-param name="ns"
					select="substring-before(substring($name, 2), '}')" />
				<xsl:with-param name="localName"
					select="substring-after($name, '}')" />
				<xsl:with-param name="type" select="$type" />
			</xsl:apply-templates>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="string($id)">
				<a href="{$id}">
					<xsl:value-of select="$qname" />
				</a>
			</xsl:when>

			<xsl:otherwise>
				<xsl:value-of select="$qname" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- ========================================================= -->
	<!--    This is a helper template to compute an unique name    -->
	<!--    using namespace. For example, it will return:          -->
	<!--       {http://www.ibm.com}PurchaseOrder                   -->
	<!-- ========================================================= -->
	<xsl:template match="*" mode="resolve">
		<xsl:param name="qname" />
		<xsl:text>{</xsl:text>
		<xsl:value-of
			select="namespace::*[name() = substring-before($qname, ':')]" />
		<xsl:text>}</xsl:text>

		<xsl:variable name="local">
			<xsl:choose>
				<xsl:when test="contains($qname, ':')">
					<xsl:value-of select="substring-after($qname, ':')" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$qname" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="$local" />
	</xsl:template>

	<xsl:variable name="baseInputDir">
		<xsl:call-template name="getBaseDirectory">
			<xsl:with-param name="schemaLocation"
				select="$xmlschemaLocation" />
		</xsl:call-template>
	</xsl:variable>


	<!-- ========================================================= -->
	<!--    This is an utility template to compute file name       -->
	<!--    as the last segment of the file path    			   -->
	<!-- ========================================================= -->
	<xsl:template name="getFileName">
		<xsl:param name="filePath" />

		<xsl:variable name="path1"
			select="substring-after($filePath, '/')">
		</xsl:variable>
		<xsl:variable name="path2"
			select="substring-after($filePath, '\')">
		</xsl:variable>

		<xsl:variable name="subpath">
			<xsl:choose>
				<xsl:when test="$path1">
					<xsl:call-template name="getFileName">
						<xsl:with-param name="filePath" select="$path1" />
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$path2">
					<xsl:call-template name="getFileName">
						<xsl:with-param name="filePath" select="$path2" />
					</xsl:call-template>
				</xsl:when>

				<xsl:otherwise>
					<xsl:value-of select="$filePath" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="$subpath" />

	</xsl:template>


	<!-- =================================================================== -->
	<!--    This is an utility template to compute the schema base directory -->
	<!-- =================================================================== -->

	<xsl:template name="getBaseDirectory">
		<xsl:param name="schemaLocation" />
		<xsl:param name="baseDir" />


		<xsl:variable name="schemaFileLocation">
			<xsl:choose>
				<xsl:when test="contains($schemaLocation, ':')">
					<xsl:value-of select="$schemaLocation" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat($baseDir, $schemaLocation)" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="newBaseDir">
			<xsl:call-template name="getFileLocation">
				<xsl:with-param name="filePath"
					select="$schemaFileLocation" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:value-of select="$newBaseDir" />
	</xsl:template>

	<!-- ========================================================= -->
	<!--    This is an utility template to compute the parent      -->
	<!--	directory                                              -->
	<!-- ========================================================= -->
	<xsl:template name="getFileLocation">
		<xsl:param name="filePath" />
		<xsl:variable name="fileName">
			<xsl:call-template name="getFileName">
				<xsl:with-param name="filePath" select="$filePath" />
			</xsl:call-template>
		</xsl:variable>
		<xsl:value-of select="substring-before($filePath, $fileName)" />
	</xsl:template>

	<!-- ====================================================================== -->
	<!--    This is a helper template to generate file name for					-->
	<!--    the imported, included or redefined schemas"			            -->
	<!-- ====================================================================== -->
	<xsl:template name="changeFileExtension">
		<xsl:param name="fileName" />
		<xsl:param name="fromExtension" select="'xsd'" />
		<xsl:param name="toExtension" select="'html'" />


		<xsl:variable name="fileNameNoExt">
			<xsl:value-of
				select="substring-before($fileName, $fromExtension)" />
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="string($fileNameNoExt)">
				<xsl:value-of
					select="concat($fileNameNoExt, $toExtension)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fileName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>





	<xsl:template match="xs:schema" mode="getAllComponents">
		<xsl:param name="schemaLocation" />
		<xsl:param name="baseDir" />
		<xsl:param name="fileType" />
		<xsl:param name="usedBySchemas" />
		<xsl:param name="componentType" />

		<xsl:variable name="ns">
			<xsl:apply-templates select="." mode="targetNamespace" />
		</xsl:variable>

		<xsl:variable name="fileName">
			<xsl:call-template name="getFileName">
				<xsl:with-param name="filePath"
					select="$schemaLocation" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="dependencyName">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), '.html')" />
		</xsl:variable>

		<xsl:variable name="dependencyNameDetails">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<xsl:variable name="outputPathDependencyName">
			<xsl:value-of
				select="concat($outputFolder, substring-before($fileName, '.xsd'), '.html')" />
		</xsl:variable>

		<xsl:variable name="outputPathDetails">
			<xsl:value-of
				select="concat($outputFolder, substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas"
				select="$usedBySchemas" />
			<xsl:with-param name="componentType"
				select="$componentType" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="xs:import | xs:include | xs:redefine"
		mode="allComponents">
		<xsl:param name="baseDir" select="." />
		<xsl:param name="usedBySchemas" />
		<xsl:param name="componentType" />

		<xsl:variable name="schemaFileLocation">
			<xsl:choose>
				<xsl:when test="contains(@schemaLocation, ':')">
					<xsl:value-of select="@schemaLocation" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat($globalBaseDir, @schemaLocation)" />
					<!-- changed from baseDir -->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="schema"
			select="document(@schemaLocation, document($schemaFileLocation))/xs:schema" />

		
		<xsl:choose>
			<xsl:when
				test="contains($usedBySchemas, $schemaFileLocation)">
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="newBaseDir">
					<xsl:call-template name="getBaseDirectory">
						<xsl:with-param name="schemaLocation"
							select="@schemaLocation" />
						<xsl:with-param name="baseDir"
							select="$baseDir" />
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="newUsedBySchemas">
					<xsl:value-of
						select="concat($usedBySchemas, ':', $schemaFileLocation)" />
				</xsl:variable>

				<xsl:apply-templates select="$schema"
					mode="getAllComponents">
					<xsl:with-param name="schemaLocation"
						select="$schemaFileLocation" />
					<xsl:with-param name="baseDir" select="$newBaseDir" />
					<xsl:with-param name="fileType"
						select="local-name(.)" />
					<xsl:with-param name="usedBySchemas"
						select="$newUsedBySchemas" />
					<xsl:with-param name="componentType"
						select="$componentType" />
				</xsl:apply-templates>

			</xsl:otherwise>

		</xsl:choose>


	</xsl:template>

	<xsl:template match="xs:schema" mode="allComponents">
		<xsl:param name="dependencyNameDetails" />
		<xsl:param name="baseDir" select="." />
		<xsl:param name="usedBySchemas" />
		<xsl:param name="componentType" />

		<xsl:if test="$componentType = 0">
			<xsl:if test="count(./xs:element)> 0">
				<xsl:apply-templates select="./xs:element"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:if test="$componentType = 1">
			<xsl:if test="count(./xs:complexType)>0">
				<xsl:apply-templates select="./xs:complexType"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:if test="$componentType = 2">
			<xsl:if test="count(./xs:simpleType)>0">
				<xsl:apply-templates select="./xs:simpleType"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:if test="$componentType = 3">
			<xsl:if test="count(./xs:attributeGroup)>0">
				<xsl:apply-templates select="./xs:attributeGroup"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:if test="$componentType = 4">
			<xsl:if test="count(./xs:attribute)>0">
				<xsl:apply-templates select="./xs:attribute"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:if test="$componentType = 5">
			<xsl:if test="count(./xs:group)>0">
				<xsl:apply-templates select="./xs:group"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:if test="$componentType = 6">
			<xsl:if test="count(./xs:notation)>0">
				<xsl:apply-templates select="./xs:notation"
					mode="allComponents">
					<xsl:with-param name="dependencyNameDetails"
						select="$dependencyNameDetails" />
					<xsl:sort select="@name" />
				</xsl:apply-templates>
			</xsl:if>
		</xsl:if>

		<xsl:apply-templates
			select="*[self::xs:include or self::xs:import or self::xs:redefine]"
			mode="allComponents">
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas"
				select="$usedBySchemas" />
			<xsl:with-param name="componentType"
				select="$componentType" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template
		match="xs:element | xs:complexType | xs:simpleType | xs:attributeGroup |
                    xs:attribute | xs:group | xs:notation"
		mode="allComponents">
		<xsl:param name="dependencyNameDetails" />
		<xsl:variable name="id">
			<xsl:apply-templates select="." mode="id">
				<xsl:with-param name="dependencyNameDetails"
					select="$dependencyNameDetails" />
			</xsl:apply-templates>
		</xsl:variable>
		<xsl:text disable-output-escaping="yes">
			&lt;a href=&quot;
		</xsl:text>
		<xsl:value-of select="$dependencyNameDetails" />
		<xsl:text disable-output-escaping="yes">#</xsl:text>
		<xsl:value-of select="$id" />
		<xsl:text disable-output-escaping="yes">
			&quot; TARGET=&quot;detailFrame&quot; &gt;
		</xsl:text>
		<xsl:value-of select="@name" />
		<xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
		<br />
	</xsl:template>


	<xsl:template match="xs:schema" mode="overall">
		<xsl:param name="schemaLocation" />
		<xsl:param name="baseDir" />

		<xsl:variable name="ns">
			<xsl:apply-templates select="." mode="targetNamespace" />
		</xsl:variable>

		<xsl:variable name="fileName">
			<xsl:call-template name="getFileName">
				<xsl:with-param name="filePath"
					select="$schemaLocation" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="dependencyName">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), '.html')" />
		</xsl:variable>

		<xsl:variable name="dependencyNameDetails">
			<xsl:value-of
				select="concat(substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<xsl:variable name="outputPathDependencyName">
			<xsl:value-of
				select="concat($outputFolder, substring-before($fileName, '.xsd'), '.html')" />
		</xsl:variable>

		<xsl:variable name="outputPathDetails">
			<xsl:value-of
				select="concat($outputFolder, substring-before($fileName, '.xsd'), 'Details.html')" />
		</xsl:variable>

		<p />
		<span class="FrameHeadingFont">Elements</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="0" />
		</xsl:apply-templates>

		<p />
		<span class="FrameHeadingFont">Complex Types</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="1" />
		</xsl:apply-templates>
		<p />
		<span class="FrameHeadingFont">Simple Types</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="2" />
		</xsl:apply-templates>
		<p />
		<span class="FrameHeadingFont">Attribute Groups</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="3" />
		</xsl:apply-templates>
		<p />
		<span class="FrameHeadingFont">Attributes</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="4" />
		</xsl:apply-templates>
		<p />
		<span class="FrameHeadingFont">Groups</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="5" />
		</xsl:apply-templates>
		<p />
		<span class="FrameHeadingFont">Notation</span>
		<br />
		<xsl:apply-templates select="." mode="allComponents">
			<xsl:with-param name="dependencyNameDetails"
				select="$dependencyNameDetails" />
			<xsl:with-param name="baseDir" select="$baseDir" />
			<xsl:with-param name="usedBySchemas" select="." />
			<xsl:with-param name="componentType" select="6" />
		</xsl:apply-templates>

	</xsl:template>

</xsl:stylesheet>

