<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
     xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="xs">
     
    <!-- ======================================================== -->
    <!--   Global element                                         -->
    <!-- ======================================================== --> 
    <xsl:template match="xs:element" mode="source">    
      <pre>         
          <xsl:apply-templates select="." mode="ctSource">
              <xsl:with-param name="indent" select="'0'"/> 
          </xsl:apply-templates>
      </pre>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Local element                                          -->
    <!-- ======================================================== -->
    <xsl:template match="xs:element" mode="ctSource"> 
       <xsl:param name="indent"/>    
       <xsl:call-template name="emitBlank">
          <xsl:with-param name="space" select="$indent"/>
       </xsl:call-template>       
       <xsl:text>&lt;</xsl:text> 
             
       <span class="src-element">
           <xsl:value-of select="name()"/>       
       </span>
        
       <!-- name attribute -->
       <xsl:if test="@name">
           <span class="src-attribute"> name</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@name"/>
           <xsl:text>"</xsl:text>
       </xsl:if>    
       
       <!-- type or ref attribute -->
       <xsl:choose>
           <xsl:when test="@ref">
               <span class="src-attribute"> ref</span>           
               <xsl:text>="</xsl:text>                    
               <xsl:value-of select="@ref"/>                            
               <xsl:text>"</xsl:text>
           </xsl:when>   
           <xsl:when test="@type"> 
               <span class="src-attribute"> type</span>
               <xsl:text>="</xsl:text>           
               <xsl:value-of select="@type"/>
               <xsl:text>"</xsl:text>                          
           </xsl:when>         
       </xsl:choose>
       
       <!-- block attribute -->
       <xsl:if test="@block">
           <span class="src-attribute"> block</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@block"/>
           <xsl:text>"</xsl:text>
       </xsl:if>                 
       
       <!-- final attribute -->
       <xsl:if test="@final">
           <span class="src-attribute"> final</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@final"/>
           <xsl:text>"</xsl:text>
       </xsl:if>     
                  
       <!-- minOccurs attribute -->
       <xsl:if test="@minOccurs">
           <span class="src-attribute"> minOccurs</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@minOccurs"/>
           <xsl:text>"</xsl:text>
       </xsl:if>     
       
       <!-- maxOccurs attribute -->
       <xsl:if test="@maxOccurs">
           <span class="src-attribute"> maxOccurs</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@maxOccurs"/>
           <xsl:text>"</xsl:text>
       </xsl:if>     
       
       <!-- fixed attribute -->
       <xsl:if test="@fixed">
           <span class="src-attribute"> fixed</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@fixed"/>
           <xsl:text>"</xsl:text>
       </xsl:if>   
       
       <!-- default attribute -->
       <xsl:if test="@default">
           <span class="src-attribute"> default</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@default"/>
           <xsl:text>"</xsl:text>
       </xsl:if>   
       
       <!-- abstract attribute -->
       <xsl:if test="@abstract">
           <span class="src-attribute"> abstract</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@abstract"/>
           <xsl:text>"</xsl:text>
       </xsl:if>   
       
       <!-- nillable attribute -->
       <xsl:if test="@nillable">
           <span class="src-attribute"> nillable</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@nillable"/>
           <xsl:text>"</xsl:text>
       </xsl:if>   
       
       <!-- substitutionGroup -->
       <xsl:if test="@substitutionGroup">
           <span class="src-attribute"> substitutionGroup</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@substitutionGroup"/>
           <xsl:text>"</xsl:text>
       </xsl:if>
       
       <!-- form attribute -->
       <xsl:if test="@form">
           <span class="src-attribute"> form</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@form"/>
           <xsl:text>"</xsl:text>
       </xsl:if>   
           
       <xsl:choose>
           <xsl:when test="@ref">                              
               <xsl:text>/&gt;</xsl:text>                
           </xsl:when>   
           <xsl:when test="@type">                              
               <xsl:text>/&gt;</xsl:text>                
           </xsl:when>
           <xsl:otherwise>
               <!-- Handle anonymous simple/complex type, and key elements if any -->
               <xsl:text>&gt;</xsl:text>
               <br/>
               <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">               
                   <xsl:with-param name="indent" select="$indent + 2"/>
               </xsl:apply-templates>
               <br/>
               <!-- emit leading space and close tag -->     
  		       <xsl:call-template name="emitBlank">
                   <xsl:with-param name="space" select="$indent"/>
               </xsl:call-template>      
               <xsl:text>&lt;/</xsl:text>
               <span class="src-element"><xsl:value-of select="name()"/></span>
               <xsl:text>&gt;</xsl:text>                                        
           </xsl:otherwise>
       </xsl:choose> 
              
       <xsl:choose>
           <xsl:when test="$indent > 0">                       
           <br/>
           </xsl:when>                
       </xsl:choose>
      
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Key, Unique and KeyRef                                 -->
    <!-- ======================================================== -->
    <xsl:template match="xs:unique | xs:key | xs:keyref" mode="ctSource">
        <xsl:param name="indent"/> 
        <br/>   
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>   
            
        <xsl:text>&lt;</xsl:text> 
        
        <span class="src-element">
           <xsl:value-of select="name()"/>       
        </span>
          
        <xsl:if test="@name">
            <span class="src-attribute"> name</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@name"/>
            <xsl:text>"</xsl:text>
        </xsl:if>
        
        <xsl:if test="@refer">
            <span class="src-attribute"> refer</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@refer"/>
            <xsl:text>"</xsl:text>
        </xsl:if>
        
        <xsl:text>&gt;</xsl:text>
        <br/>
        
        <!-- Process selector and field -->    
        <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">               
            <xsl:with-param name="indent" select="$indent + 2"/>
        </xsl:apply-templates>
        
        <!-- emit leading space and close tag -->     
  		<xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>    
        <xsl:text>&lt;/</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>      
      
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   selector element                                       -->
    <!-- ======================================================== -->
    <xsl:template match="xs:selector" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>       
        <xsl:text>&lt;</xsl:text> 
        
        <span class="src-element">
           <xsl:value-of select="name()"/>       
        </span>
        
        <xsl:if test="@xpath">
            <span class="src-attribute"> xpath</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@xpath"/>
            <xsl:text>"</xsl:text>
        </xsl:if>
        
        <xsl:text>/&gt;</xsl:text>   
        <br/>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   field element                                       -->
    <!-- ======================================================== -->
    <xsl:template match="xs:field" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>       
        <xsl:text>&lt;</xsl:text> 
        
        <span class="src-element">
           <xsl:value-of select="name()"/>       
        </span>
        
        <xsl:if test="@xpath">
            <span class="src-attribute"> xpath</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@xpath"/>
            <xsl:text>"</xsl:text>
        </xsl:if>
        
        <xsl:text>/&gt;</xsl:text>
        <br/>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Local any element                                      -->
    <!-- ======================================================== -->
    <xsl:template match="xs:any" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>       
        <xsl:text>&lt;</xsl:text> 
          
       <span class="src-element">
           <xsl:value-of select="name()"/>       
       </span>  
        
       <xsl:if test="@minOccurs">
           <span class="src-attribute"> minOccurs</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@minOccurs"/>
            <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:if test="@maxOccurs">
           <span class="src-attribute"> maxOccurs</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@maxOccurs"/>
            <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:if test="@namespace">
           <span class="src-attribute"> namespace</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@namespace"/>
            <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:if test="@processContents">
           <span class="src-attribute"> processContents</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@processContents"/>
            <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:text>/&gt;</xsl:text> 
       <br/>           
    </xsl:template>    
    
    <!-- ================================================================== -->
    <!--    Local Group Ref                                                -->
    <!-- ================================================================== -->
    <xsl:template match="xs:group" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>       
        <xsl:text>&lt;</xsl:text> 
          
       <span class="src-element">
           <xsl:value-of select="name()"/>       
       </span>  
       
       <xsl:if test="@ref">                 
           <span class="src-attribute"> ref</span>
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@ref"/>
           <xsl:text>"</xsl:text>         
       </xsl:if> 
       
       <xsl:if test="@minOccurs">
           <span class="src-attribute"> minOccurs</span>
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@minOccurs"/>
           <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:if test="@maxOccurs">
           <span class="src-attribute"> maxOccurs</span>
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@maxOccurs"/>
           <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:text>/&gt;</xsl:text>        
       <br/>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--    annonymous complex type                               -->
    <!-- ======================================================== -->
    <xsl:template match="xs:complexType" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>       
        
        <xsl:text>&lt;</xsl:text>
        <span class="src-element">
            <xsl:value-of select="name()"/>
        </span>
             
        <xsl:if test="@name">
            <span class="src-attribute"> name</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@name"/>
            <xsl:text>"</xsl:text>
        </xsl:if>
                  
        <xsl:text>&gt;</xsl:text>                         
        <br/>            
        
        <!-- complex type content -->     
        <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource"> 
            <xsl:with-param name="indent" select="$indent + 2"/>
  		</xsl:apply-templates>
  		
  		<!-- emit leading space and close tag -->     
  		<xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>      
             
        <xsl:text>&lt;/</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>        
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Global complex type                                    -->
    <!-- ======================================================== -->
    <xsl:template match="xs:complexType" mode="source">           
       <tr>
          <td><span class="headings">Source</span></td>
          <td>           
              <pre>
                  <xsl:apply-templates select="." mode="ctSource">
                      <xsl:with-param name="indent" select="'0'"/>
                  </xsl:apply-templates>          
              </pre>
          </td>                                            
       </tr>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Global group                                           -->
    <!-- ======================================================== -->
    <xsl:template match="xs:group" mode="source">           
       <tr>
          <td><span class="headings">Source</span></td>
          <td>           
              <pre>
                  <xsl:text>&lt;</xsl:text>
                  <span class="src-element">
                  <xsl:value-of select="name()"/>
                  </span>
                  
                  <xsl:if test="@name">
                      <span class="src-attribute"> name</span>
                      <xsl:text>="</xsl:text>
                      <xsl:value-of select="@name"/>
                      <xsl:text>"</xsl:text>
                  </xsl:if>
                  
                  <xsl:text>&gt;</xsl:text>   
                  <br/>
                  
                  <!-- group content -->     
                  <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource"> 
                      <xsl:with-param name="indent" select="2"/>
  		          </xsl:apply-templates>         
  		          
  		          <xsl:text>&lt;/</xsl:text>
                  <span class="src-element"><xsl:value-of select="name()"/></span>
                  <xsl:text>&gt;</xsl:text>                                         
              </pre>
          </td>                                            
       </tr>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Global attribute group                                    -->
    <!-- ======================================================== -->
    <xsl:template match="xs:attributeGroup" mode="source">           
       <tr>
          <td><span class="headings">Source</span></td>
          <td>           
              <pre>
                  <xsl:text>&lt;</xsl:text>
                  <span class="src-element">
                  <xsl:value-of select="name()"/>
                  </span>
                  
                  <xsl:if test="@name">
                      <span class="src-attribute"> name</span>
                      <xsl:text>="</xsl:text>
                      <xsl:value-of select="@name"/>
                      <xsl:text>"</xsl:text>
                  </xsl:if>
                  
                  <xsl:text>&gt;</xsl:text>   
                  <br/>
                  <xsl:variable name="indent" select="'0'"/>
                  
                  <!-- attribute grp content -->     
                  <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource"> 
                     <xsl:with-param name="indent" select="$indent + 2"/>
  		          </xsl:apply-templates>         
  		          
  		          <xsl:text>&lt;/</xsl:text>
                  <span class="src-element"><xsl:value-of select="name()"/></span>
                  <xsl:text>&gt;</xsl:text>
              </pre>
          </td>                                            
       </tr>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Global simple type                                    -->
    <!-- ======================================================== -->
    <xsl:template match="xs:simpleType" mode="source">           
       <tr>
          <td><span class="headings">Source</span></td>
          <td>           
              <pre>
                  <xsl:apply-templates select="." mode="ctSource">
                      <xsl:with-param name="indent" select="'0'"/>
                  </xsl:apply-templates>          
              </pre>
          </td>                                            
       </tr>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--    annonymous simple type                               -->
    <!-- ======================================================== -->
    <xsl:template match="xs:simpleType" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>       
        
        <xsl:text>&lt;</xsl:text>
        <span class="src-element">
            <xsl:value-of select="name()"/>
        </span>
             
        <xsl:if test="@name">
            <span class="src-attribute"> name</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@name"/>
            <xsl:text>"</xsl:text>
        </xsl:if>
                  
        <xsl:text>&gt;</xsl:text>                         
        <br/>            
        
        <!-- simple type content -->     
        <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource"> 
            <xsl:with-param name="indent" select="$indent + 2"/>
  		</xsl:apply-templates>
  		
  		<!-- emit leading space and close tag -->     
  		<xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>      
             
        <xsl:text>&lt;/</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>               
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   simple type - restriction/list/union                   -->
    <!--     make sure we differentiate from complex type         -->
    <!--     restriction                                          -->
    <!-- ======================================================== -->
    <xsl:template match="xs:simpleType/xs:list | xs:simpleType/xs:restriction | 
                  xs:simpleType/xs:union" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
        
        <xsl:choose>
            <xsl:when test="@base">                                   
                <span class="src-attribute"> base</span>
                <xsl:text>="</xsl:text>
                <xsl:value-of select="@base"/>
                <xsl:text>"</xsl:text>         
                <xsl:text>&gt;</xsl:text>                 
                <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
                    <xsl:with-param name="indent" select="$indent+2"/>
                </xsl:apply-templates>      
                <br/>
            </xsl:when>         
            <xsl:when test="@itemType">
                <span class="src-attribute"> itemType</span>
                <xsl:text>="</xsl:text>
                <xsl:value-of select="@itemType"/>
                <xsl:text>"</xsl:text>
                <xsl:text>&gt;</xsl:text>                 
                <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
                    <xsl:with-param name="indent" select="$indent+2"/>
                </xsl:apply-templates>    
                <br/>
            </xsl:when>        
            <xsl:when test="@memberTypes">
                <span class="src-attribute"> memberTypes</span>
                <xsl:text>="</xsl:text>
                <xsl:value-of select="@memberTypes"/>
                <xsl:text>"</xsl:text>
                <xsl:text>&gt;</xsl:text>                                               
                <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
                    <xsl:with-param name="indent" select="$indent+2"/>
                </xsl:apply-templates>  
                <br/>              
            </xsl:when>            
            <xsl:otherwise>
                <xsl:text>&gt;</xsl:text>
                <!-- annonymous simple type -->
                <br/>                
                <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
                    <xsl:with-param name="indent" select="$indent + 2"/>
                </xsl:apply-templates>                                                                                        
            </xsl:otherwise>
        </xsl:choose>
        
        <!-- emit leading space and close tag -->             
  		<xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>      
             
        <xsl:text>&lt;/</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>
        <br/>
    </xsl:template>     
    
    <!-- ======================================================== -->
    <!--   Matches all simple type facets                         -->   
    <!-- ======================================================== -->
    <xsl:template match="xs:length | xs:minLength | xs:maxLength |
                         xs:whiteSpace | xs:maxInclusive | xs:minInclusive |
                         xs:maxExclusive | xs:minExclusive | xs:totalDigits |
                         xs:fractionDigits | xs:pattern | xs:enumeration"
                  mode="ctSource">                     
        <xsl:param name="indent"/>        
        <br/>
        <xsl:call-template name="emitBlank">
           <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template> 
            
        <xsl:text>&lt;</xsl:text>                
        <span class="src-element"><xsl:value-of select="name()"/></span>
        <span class="src-attribute"> value</span>
        <xsl:text>="</xsl:text>            
        <xsl:value-of select="@value"/>
        <xsl:text>"/&gt;</xsl:text>                                           
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Global attribute                                       -->
    <!-- ======================================================== --> 
    <xsl:template match="xs:attribute" mode="source">    
      <pre>         
          <xsl:apply-templates select="." mode="ctSource">
              <xsl:with-param name="indent" select="'0'"/> 
          </xsl:apply-templates>
      </pre>
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   Local attribute                                        -->
    <!-- ======================================================== -->
    <xsl:template match="xs:attribute | xs:attributeGroup" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;</xsl:text>
            <span class="src-element"><xsl:value-of select="name()"/></span>
            
        <xsl:if test="@name">
            <span class="src-attribute"> name</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@name"/>
            <xsl:text>"</xsl:text>
        </xsl:if>  
        
        <!-- attribute ref or type -->
        <xsl:choose>
            <xsl:when test="@ref">
               <span class="src-attribute"> ref</span>           
               <xsl:text>="</xsl:text>                    
               <xsl:value-of select="@ref"/>
               <xsl:text>"</xsl:text>                          
            </xsl:when>   
            <xsl:when test="@type"> 
                <span class="src-attribute"> type</span>
                <xsl:text>="</xsl:text>           
                <xsl:value-of select="@type"/>
                <xsl:text>"</xsl:text>                            
            </xsl:when>
        </xsl:choose>
        
        <!-- default attribute -->
        <xsl:if test="@default">
            <span class="src-attribute"> default</span>           
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@default"/>
            <xsl:text>"</xsl:text>
        </xsl:if>  
        
        <!-- fixed attribute -->
        <xsl:if test="@fixed">
            <span class="src-attribute"> fixed</span>           
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@fixed"/>
            <xsl:text>"</xsl:text>
        </xsl:if>  
        
        <!-- use attribute -->
        <xsl:if test="@use">
            <span class="src-attribute"> use</span>           
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@use"/>
            <xsl:text>"</xsl:text>
        </xsl:if>  
                            
        <!-- form attribute -->
        <xsl:if test="@form">
            <span class="src-attribute"> form</span>           
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@form"/>
            <xsl:text>"</xsl:text>
        </xsl:if>                         
    
        <xsl:choose>
           <xsl:when test="@ref">               
               <xsl:text>/&gt;</xsl:text>                
           </xsl:when>   
           <xsl:when test="@type">                
               <xsl:text>/&gt;</xsl:text>                
           </xsl:when>
           <xsl:otherwise>
               <!-- Handle anonymous simple type -->
               <xsl:text>&gt;</xsl:text>
               <br/>
               <xsl:apply-templates select="xs:simpleType" mode="ctSource">
                   <xsl:with-param name="indent" select="$indent + 2"/>
               </xsl:apply-templates>
               <br/>
               <!-- emit leading space and close tag -->     
  		       <xsl:call-template name="emitBlank">
                   <xsl:with-param name="space" select="$indent"/>
               </xsl:call-template>      
               <xsl:text>&lt;/</xsl:text>
               <span class="src-element"><xsl:value-of select="name()"/></span>
               <xsl:text>&gt;</xsl:text>                                        
           </xsl:otherwise>
        </xsl:choose>     
        
        <xsl:choose>
           <xsl:when test="$indent > 0">                       
              <br/>
           </xsl:when>                
        </xsl:choose>        
    </xsl:template>
    
    <!-- ================================================================== -->
    <!--           Process an any attribute                                 -->
    <!-- ================================================================== -->
    <xsl:template match="xs:anyAttribute" mode="ctSource">           
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
        
        <xsl:if test="@namespace">
           <span class="src-attribute"> namespace</span>
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@namespace"/>
           <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:if test="@processContents">
           <span class="src-attribute"> processContents</span>
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@processContents"/>
           <xsl:text>"</xsl:text>
       </xsl:if>
       
       <xsl:text>/&gt;</xsl:text>  
       <br/>
    </xsl:template>
    
    <!-- ======================================================== -->    
    <!--   content                                                -->
    <!-- ======================================================== -->
    <xsl:template match="xs:all | xs:sequence | xs:choice" mode="ctSource">
        <xsl:param name="indent"/>    
        
        <!-- Emit the open tag -->
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;</xsl:text>
            <span class="src-element"><xsl:value-of select="name()"/></span>
            
        <!-- minOccurs attribute -->
        <xsl:if test="@minOccurs">
           <span class="src-attribute"> minOccurs</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@minOccurs"/>
           <xsl:text>"</xsl:text>
        </xsl:if>     
       
        <!-- maxOccurs attribute -->
        <xsl:if test="@maxOccurs">
           <span class="src-attribute"> maxOccurs</span>           
           <xsl:text>="</xsl:text>
           <xsl:value-of select="@maxOccurs"/>
           <xsl:text>"</xsl:text>
        </xsl:if>     
        
        <xsl:text>&gt;</xsl:text>                 
        <br/>
        
        <!-- Emit the content -->
        <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
            <xsl:with-param name="indent" select="$indent + 2"/>
		</xsl:apply-templates>
			
		<!-- Emit the end tag -->
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;/</xsl:text>
            <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>
        <br/>    
    </xsl:template>
    
    <!-- ======================================================== -->    
    <!--   Complex type - simpleContent and complexContent        -->
    <!-- ======================================================== -->
    <xsl:template match="xs:simpleContent | xs:complexContent" mode="ctSource">
        <xsl:param name="indent"/>    
        
        <!-- Emit the open tag -->
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;</xsl:text>
            <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>         
        <br/>
        
        <!-- Emit the content -->
        <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
            <xsl:with-param name="indent" select="$indent + 2"/>
		</xsl:apply-templates>
			
		<!-- Emit the end tag -->
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;/</xsl:text>
            <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>
        <br/>    
    </xsl:template>
    
    <!-- ======================================================== -->
    <!--   complex type - simpleContent/complexContent            -->
    <!--     - restriction & extension                            -->   
    <!-- ======================================================== -->
    <xsl:template match="xs:extension | xs:restriction" mode="ctSource">
        <xsl:param name="indent"/>    
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;</xsl:text>
        <span class="src-element"><xsl:value-of select="name()"/></span>
                             
        <xsl:if test="@base">
            <span class="src-attribute"> base</span>
            <xsl:text>="</xsl:text>
            <xsl:value-of select="@base"/>
            <xsl:text>"</xsl:text>         
            <xsl:text>&gt;</xsl:text>       
        </xsl:if> 
        <br/>
        
        <!-- Emit the content -->
        <xsl:apply-templates select="*[not(self::xs:annotation)]" mode="ctSource">
            <xsl:with-param name="indent" select="$indent + 2"/>
		</xsl:apply-templates>
		
        <!-- Emit the end tag -->
        <xsl:call-template name="emitBlank">
            <xsl:with-param name="space" select="$indent"/>
        </xsl:call-template>
        
        <xsl:text>&lt;/</xsl:text>
            <span class="src-element"><xsl:value-of select="name()"/></span>
        <xsl:text>&gt;</xsl:text>
        <br/>    
    </xsl:template>
    
    <xsl:template name="emitBlank">
        <xsl:param name="space"/>
        <xsl:if test="$space > 0">
            <xsl:text> </xsl:text>
            <xsl:call-template name="emitBlank">
                <xsl:with-param name="space" select="$space - 1"/>
            </xsl:call-template>            
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>   